*CODE FOR ANALYSIS INCLUDED IN THE ONLINE APPENDIX 

cd c:\stata\data\srilanka\
use data\SLMSMaster_web.dta, clear
*This data set contains only indirectly affected and unaffected, 9 rounds
drop if ets==1 | ets==.
drop if wave>=10

*---Trimming points---*
tsset sheno wave
gen abschange=prof-L.prof
gen perchange=100*(prof-L.prof)/L.prof

*cuts for top 0.5% (about one observation per wave, on average)
egen xtreme_high=pctile(perchange), p(99.5)
egen xtreme_low=pctile(perchange), p(.5)
egen xtreme_high_abs=pctile(abschange), p(99.5)
egen xtreme_low_abs=pctile(abschange), p(.5)

sum perchange, de

egen minchange=min(perchange), by(sheno)
egen maxchange=max(perchange), by(sheno)

*sample 2 trims the upper .5%, but both percentage and absolute changes
gen sample2=1 if waves>=3 & ets>1 &  (perchange <=xtreme_high | perchange==.) & (abschange<=xtreme_high_abs  | abschange==.)

gen logprof=log(realprof)
*For Appendix Table A-2
*replace amount=0 if amount== .25

log using c:\stata\logs\srl\qjerevise_appendix, replace
replace K2_noland=K2_noland/10000
gen hourlywage=prof/(ownhours*4.2)

gen equip100=equipamount==1
gen equip200=equipamount==2
gen cash100=cashamount==1
gen cash200=cashamount==2

gen lK2_nolandnew=log(K2_nolandnew)
replace famhours=0 if famhours==. & wave>=6 & sample2==1


gen etreat=1 if wave==2 & amount>0 & amount~=.
egen earlytreat=max(etreat), by(sheno)
replace earlytreat=0 if earlytreat==.
gen latetreat=1
replace latetreat=0 if earlytreat==1|evertreat==0
gen timesince=wave-1 if earlytreat==1
replace timesince=wave-3 if latetreat==1
replace timesince=0 if timesince==.
replace timesince=0 if timesince<0

gen firstyear=timesince<=4
gen secondyear=timesince>=5 & timesince~=.

gen firstyear_amount=amount*firstyear
gen secondyear_amount=amount*secondyear

gen amount100=amount==1 if amount~=.
gen amount200=amount==2 if amount~=.

*pooling manufacturing and retail
gen man=ind=="man" if ind~="."
gen trade=ind=="trade" if ind~="."
gen amount_man=amount*man
gen amount_trade=amount*trade
for num 2/9: gen man_waveX=man*waveX
xtreg realprof amount_man amount_trade wave2-wave9 man_wave2-man_wave9  if sample2==1, i(sheno) fe cluster(sheno)
test amount_trade=amount_man

gen gend=gender if wave==1
egen gender_1=mean(gender), by(sheno)

gen ednEN=ednyearsFIRM
gen femlow=gender_1==2 & ednEN<=7 if gender_1~=. & ednEN~=.
gen femmed=gender_1==2 & ednEN>=8 & ednEN<=10 if gender_1~=. & ednEN~=.
gen femhi=gender_1==2 & ednEN>=11 if gender_1~=. & ednEN~=.

gen malelow=gender_1==1 & ednEN<=7 if gender_1~=. & ednEN~=.
gen malemed=gender_1==1 & ednEN>=8 & ednEN<=10 if gender_1~=. & ednEN~=.
gen malehi=gender_1==1 & ednEN>=11 if gender_1~=. & ednEN~=.

for var femlow femmed femhi malelow malemed malehi: sum hourlywage if X==1, det
gen mcat_hourly=7.9 if femlow==1
replace mcat_hourly=11.9 if femmed==1
replace mcat_hourly=10.6 if femhi==1
replace mcat_hourly=15.9 if malelow==1
replace mcat_hourly=17.3 if malemed==1
replace mcat_hourly=15.1 if malehi==1

for var femlow femmed femhi malelow malemed malehi:gen hours_X=(ownhours*4.2)*X

*Use coefficeints from this regression:
reg prof age  femlow femmed femhi malelow malemed malehi K2_noland  hours_femlow- hours_malehi if wave==1
gen reg_hourlywage=0 if femlow==1 | femmed==1
replace reg_hourlywage=9.3 if femhi==1
replace reg_hourlywage=3.0 if malelow==1
replace reg_hourlywage=4.8 if malemed==1
replace reg_hourlywage=7.5 if malehi==1

gen adjprof3=realprof-(reg_hourlywage*4.2*ownhours)
gen adjprof4=realprof-(mcat_hourly*4.2*ownhours)

gen amount_femaleverified=amount*femaleverified
for num 2/10: gen femaleverified_waveX=femaleverified*waveX
gen K_noland_femaleverified=K2_noland*femaleverified

*table 2 with the same sample for all regressions, for online appendix
xtreg K2_nolandnew equip100 equip200 cash100 cash200 wave2-wave9   if sample2==1 & realprof~=. & ownhours~=., i(sheno) fe cluster(sheno)
xtreg lK2_nolandnew equip100 equip200 cash100 cash200 wave2-wave9   if sample2==1 & realprof~=. & ownhours~=., i(sheno) fe cluster(sheno)
xtreg realprof equip100 equip200 cash100 cash200 wave2-wave9   if sample2==1 & K2_nolandnew~=. & ownhours~=., i(sheno) fe cluster(sheno)
xtreg logprof equip100 equip200 cash100 cash200 wave2-wave9   if sample2==1 & K2_nolandnew~=. & ownhours~=., i(sheno) fe cluster(sheno)
xtreg ownhours equip100 equip200 cash100 cash200 wave2-wave9   if sample2==1 & K2_nolandnew~=. & realprof~=., i(sheno) fe cluster(sheno)


*unpaid hours worked (for appendix)
replace famhours=0 if famhours==. & wave>=6 & sample2==1
xtreg famhours equip100 equip200 cash100 cash200 wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)
xtreg nonfamhours equip100 equip200 cash100 cash200 wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)


*interaction effects
gen p_ednyears=ednyears
************************

for var nwageworkers otherbusworkers assetindex p_ednyears p_digitspan p_ability3  coeffvar p_lotBcrra overallliferisk   : egen m_X=mean(X)
 for var nwageworkers otherbusworkers assetindex p_ednyears p_digitspan p_ability3  coeffvar p_lotBcrra overallliferisk  :   gen dm_X=X-m_X

for var  nwageworkers otherbusworkers assetindex p_ednyears p_digitspan  p_ability3  coeffvar p_lotBcrra overallliferisk  :gen amount_X=amount*dm_X
for num 2/9: gen nwageworkers_waveX=dm_nwageworkers*waveX
for num 2/9: gen otherbusworkers_waveX=dm_otherbusworkers*waveX
for num 2/9: gen assetindex_waveX=dm_assetindex*waveX
for num 2/9: gen p_ednyears_waveX=dm_p_ednyears*waveX
for num 2/9: gen p_digitspan_waveX=dm_p_digitspan*waveX
for num 2/9: gen p_ability3_waveX=dm_p_ability3*waveX
for num 2/9: gen coeffvar_waveX=dm_coeffvar*waveX
for num 2/9: gen p_lotBcrra_waveX=dm_p_lotBcrra*waveX
for num 2/9: gen overallliferisk_waveX=dm_overallliferisk*waveX


*NOW ROBUSTNESS CHECKS FOR THE APPENDIX

*More on linearity of returns
*gen initk=K2_nolandnew if wave==1
*egen initK=mean(initk), by(sheno)
gen amount_initK=amount*initK
xtreg realprof amount amount_initK wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)
xtreg adjprof3 amount amount_initK wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)

*Referee 2 wants interactions on first stage regressions
*above/below median ability
egen med_ability3=pctile(p_ability3), p(50)
gen low_ability=p_ability3<med_ability if p_ability3~=.
gen prof_rev1=prof/rev if wave==1
gen prof_cap=prof/(K2_nolandnew) if wave==1

egen profit_sales=mean(prof_rev1), by(sheno)
egen profit_capital=mean(prof_cap), by(sheno)
for var profit_sales profit_capital low_ability: gen amount_X=amount*X
for num 2/9: gen low_ability_waveX=low_ability*waveX
for num 2/9: gen profit_sales_waveX=profit_sales*waveX
for num 2/9: gen profit_capital_waveX=profit_capital*waveX

for var p_lotBcrra coeffvar p_ednyears p_digitspan p_ability3 low_ability assetindex : ///
   xtreg K2_nolandnew amount amount_X wave2-wave9 X_wave2-X_wave9 if ets>1 & sample2==1, fe i(sheno)  cluster (sheno)

xtreg K2_nolandnew amount amount_profit_sales wave2-wave9 profit_sales_wave2-profit_sales_wave9 if ets>1 & sample2==1 & profit_sales>.05 & profit_sales<2.5, fe i(sheno)  cluster (sheno)
xtreg K2_nolandnew amount amount_profit_capital wave2-wave9 profit_capital_wave2-profit_capital_wave9 if ets>1 & sample2==1 & profit_capital>.015 & profit_capital<5, fe i(sheno)  cluster (sheno)

* Referee 3 wants us to look at revenues-costs, adjusted
replace revtot=rev if wave==1
replace exptot=exp if wave==1
*for num 8/9: egen muX=mean(mu_X), by(sheno)
gen MU=(mu7+mu8+mu9)/3

cor rev revmu

gen cur_inputs=revmu/MU
gen exptot_markup=exptot - inputs + cur_inputs
gen profcalc_adj_mu=revtot-exptot_markup
gen realprof_calc_mu=profcalc_adj_mu if wave==1

replace realprof_calc_mu=profcalc_adj_mu*187.4/187.3 if wave==2 /*base March05, w2 June05*/
replace realprof_calc_mu=profcalc_adj_mu*187.4/187.3 if wave==3 /*w3 Sept05*/
replace realprof_calc_mu=profcalc_adj_mu*187.4/195.6 if wave==4 /*w4 Dec05*/
replace realprof_calc_mu=profcalc_adj_mu*187.4/194.9 if wave==5 /*w5 March06*/
replace realprof_calc_mu=profcalc_adj_mu*187.4/207.3 if wave==6 /*w6 June06*/
replace realprof_calc_mu=profcalc_adj_mu*187.4/208.8 if wave==7 /*w7 Sept06*/
replace realprof_calc_mu=profcalc_adj_mu*187.4/230.6 if wave==8 /*w8 Dec06*/
replace realprof_calc_mu=profcalc_adj_mu*187.4/231.2 if wave==9 /*w9 March07*/

tsset sheno wave
gen calc_abschange=realprof_calc_mu-L.realprof_calc_mu
gen calc_perchange=100*(realprof_calc_mu-L.realprof_calc_mu)/L.realprof_calc_mu

egen calc_xtreme_high=pctile(calc_perchange), p(99.5)
egen calc_xtreme_high_abs=pctile(calc_abschange), p(99.5)

gen sample_calc=1 if waves>=3 & (calc_perchange <=calc_xtreme_high | calc_perchange==.) ///
& (calc_abschange<=calc_xtreme_high_abs  | calc_abschange==.)

xtreg realprof_calc_mu amount  wave2-wave9    if ets>1 & sample_calc==1, fe i(sheno)  cluster (sheno)

*Referee 3 wants us to look at other alternative outcome measures
for var exp inputs rev inv: xtreg X amount  wave2-wave9    if ets>1 & sample2==1, fe i(sheno)
for var exp inputs rev inv: gen lX=log(X+1)
for var lexp linputs lrev inv: xtreg X amount  wave2-wave9    if ets>1 & sample2==1, fe i(sheno)

*Does keeping books affect results?
gen even=sheno/2==int(sheno/2)
gen books=even==0 & (wave>=3 & wave<=5)
gen amount_books=amount*books

xtreg realprof amount books amount_books wave2-wave9   if sample2==1 , i(sheno) fe cluster (sheno)

*does treatment affect the reported markup?
gen treated=evertreat==1 | evertreat==2 if evertreat~=.
ttest MU if wave==1, by(treated)

*interact treatment with % spent on inventories: Do profits take less time to materialize with inventories? (Ref 3)
gen perc_inv=inv_spend/trtmnt_reported
gen perc_eq=eq_spend/trtmnt_reported
for var perc_inv perc_eq inv_spend eq_spend: replace X=0 if amount<1
for var inv_spend eq_spend: replace X=X/10000
*inv_spend and eq_spend are the actual expenditure amounts, and hence endogenous. Translate them to percentages, then multiply by treatment amount
gen inv_amount=perc_inv*amount
gen eq_amount=perc_eq*amount
egen evercash=max(cashamount),by(sheno)
egen everequip=max(equipamount),by(sheno)
xtreg realprof inv_amount eq_amount  wave2-wave9    if ets>1 & sample2==1 & trtmnt_reported==trtmnt_actual, fe i(sheno)  cluster (sheno)
xtreg realprof inv_amount eq_amount  wave2-wave9    if ets>1 & sample2==1 & evercash<1, fe i(sheno)  cluster (sheno)
xtreg realprof inv_amount eq_amount  wave2-wave9    if ets>1 & sample2==1 & evercash<1 & (timesince==0 | timesince<=2), fe i(sheno) cluster (sheno)
xtreg realprof inv_amount eq_amount  wave2-wave9    if ets>1 & sample2==1 & evercash<1 & (timesince==0 | timesince>2), fe i(sheno) cluster (sheno)
*(This is perhaps a bit of a puzzle, because both equipment and inventories seem to have similar impacts on sales and ///
    even inventory levels, but not on profits.)
xtreg rev inv_amount eq_amount  wave2-wave9    if ets>1 & sample2==1 & evercash<1, fe i(sheno) cluster (sheno)
xtreg inv inv_amount eq_amount  wave2-wave9    if ets>1 & sample2==1 & evercash<1, fe i(sheno) cluster (sheno)
*(But using logs reverses this)
xtreg lrev inv_amount eq_amount  wave2-wave9    if ets>1 & sample2==1 & evercash<1, fe i(sheno)
xtreg linv inv_amount eq_amount  wave2-wave9    if ets>1 & sample2==1 & evercash<1, fe i(sheno)


*pre-treatment plus the wave after treatment
xtreg realprof amount  wave2-wave9    if ets>1 & (treatmentround==. | (treatmentround==1 & (wave==1 | wave==2)) ///
| treatmentround==2 & (wave<=3 | wave==4))  & sample2==1 & wave<=5 , fe i(sheno) cluster (sheno)

*pre-treatment plus the two waves after treatment
xtreg realprof amount  wave2-wave9    if ets>1 & (treatmentround==. | (treatmentround==1 & (wave<=3)) ///
| treatmentround==2 & (wave<=5))  & sample2==1 & wave<=5 , fe i(sheno) cluster (sheno)

xtreg realprof amount  wave2-wave9    if ets>1 & sample2==1, fe i(sheno) cluster (sheno)


*collapse pre/post observations to pre/post means and run with 2 obs per firm (round 3 treatments only)
*Need to do this one treatment at a time, to get proper comparison group
*Round 1 treatment
tab treatmentround
mvencode  treatmentround,mv(5)
recode treatmentround (2=3)
tab treatmentround
gen prof_pre=realprof if wave<=3
gen prof_post=realprof if wave>3
egen realprof_pre=mean(prof_pre), by(sheno)
egen realprof_post=mean(prof_post), by(sheno)

gen realprof_three=realprof_pre if wave<=3 & treatmentround~=1
replace realprof_three=realprof_post if wave>3 & treatmentround~=1
xtreg realprof_three amount wave2-wave9   if sample2==1 & (wave==1 | wave==4) & treatmentround~=1, i(sheno) fe 
tab treatmentround if sample2==1 & (wave==1 | wave==9) & treatmentround~=1
tab treatmentround if sample2==1 & (wave==1)

*Now for round 1, with control group switched to 1 vs 2-9
gen prof_pre1=realprof if wave<=1
gen prof_post1=realprof if wave>1
egen realprof_pre1=mean(prof_pre1), by(sheno)
egen realprof_post1=mean(prof_post1), by(sheno)

gen realprof_one=realprof_pre if wave<=1 & treatmentround~=3
replace realprof_one=realprof_post if wave>1 & treatmentround~=3
xtreg realprof_one amount wave2-wave9   if sample2==1 & (wave==1 | wave==2) & treatmentround~=3, i(sheno) fe 
tab treatmentround if sample2==1 & (wave==1 | wave==9) & treatmentround~=3

log close
