cd c:\stata\data\srilanka\
use data\SLMSMaster_web.dta, clear
gen shen=sheno if wave==11
egen miss=max(shen), by(sheno)
drop if miss==.

*This data set contains only indirectly affected and unaffected, 9 rounds
drop if ets==1 | ets==.
drop if wave>=10

*---Trimming points---*
tsset sheno wave
gen abschange=prof-L.prof
gen perchange=100*(prof-L.prof)/L.prof

*cuts for top 0.5% (about one observation per wave, on average)
egen xtreme_high=pctile(perchange), p(99.5)
egen xtreme_low=pctile(perchange), p(.5)
egen xtreme_high_abs=pctile(abschange), p(99.5)
egen xtreme_low_abs=pctile(abschange), p(.5)

sum perchange, de

egen minchange=min(perchange), by(sheno)
egen maxchange=max(perchange), by(sheno)

*sample 2 trims the upper .5%, but both percentage and absolute changes
gen sample2=1 if waves>=3 & ets>1 &  (perchange <=xtreme_high | perchange==.) & (abschange<=xtreme_high_abs  | abschange==.)

************************
gen logprof=log(realprof)

log using c:\stata\logs\srl\qjerevise_web, replace
*Table 1: Comaprison of means at bottom of file

*** TABLE 2 - ITT by type of treatment
** 9 waves
gen equip100=equipamount==1
gen equip200=equipamount==2
gen cash100=cashamount==1
gen cash200=cashamount==2

* IMPACT ON CAPITAL STOCK
xtreg K2_nolandnew equip100 equip200 cash100 cash200 wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)
test equip100=cash100 
test equip200=cash200
test equip100=equip200
test cash100=cash200

* In logs
gen lK2_nolandnew=log(K2_nolandnew)
xtreg lK2_nolandnew equip100 equip200 cash100 cash200 wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)
test equip100=cash100 
test equip200=cash200
test equip100=equip200
test cash100=cash200

* IMPACT ON OWN HOURS
xtreg ownhours equip100 equip200 cash100 cash200 wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)
test equip100=cash100 
test equip200=cash200
test equip100=equip200
test cash100=cash200

* IMPACT ON REAL PROFITS
xtreg realprof equip100 equip200 cash100 cash200 wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)
test equip100=cash100 
test equip200=cash200
test equip100=equip200
test cash100=cash200

* In logs
xtreg logprof equip100 equip200 cash100 cash200 wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)
test equip100=cash100 
test equip200=cash200
test equip100=equip200
test cash100=cash200


*TABLE 3
*Effect of trimming
xtreg realprof amount wave2-wave9   if waves>=3, i(sheno) fe cluster(sheno)
xtreg realprof amount wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)


*Show that pooling of data is reasonable:
*pooling across time
gen etreat=1 if wave==2 & amount>0 & amount~=.
egen earlytreat=max(etreat), by(sheno)
replace earlytreat=0 if earlytreat==.
gen latetreat=1
replace latetreat=0 if earlytreat==1|evertreat==0
gen timesince=wave-1 if earlytreat==1
replace timesince=wave-3 if latetreat==1
replace timesince=0 if timesince==.
replace timesince=0 if timesince<0

gen firstyear=timesince<=4
gen secondyear=timesince>=5 & timesince~=.

gen firstyear_amount=amount*firstyear
gen secondyear_amount=amount*secondyear

xtreg realprof firstyear_amount secondyear_amount  wave2-wave9   if sample2==1 , i(sheno) fe cluster(sheno)
test firstyear_amount= secondyear_amount

*Pooling inkind vs. equipment, 100 and 200
xtreg logprof amount wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)
xtreg realprof equipamount cashamount wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)
test equipamount=cashamount

gen amount100=amount==1 if amount~=.
gen amount200=amount==2 if amount~=.
xtreg realprof amount100 amount200 wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)
test amount200=amount100
test amount200=2*amount100

*Pooling zones 2 and 3; Supress "drop if ets==1" statement FOR REGRESSION USING ALL THREE ZONES
for num 2/3: gen zoneX=ets==X
for num 2/3: gen amount_zoneX=amount*zoneX
for num 2/9: gen zone2_waveX=zone2*waveX
for num 2/9: gen zone3_waveX=zone3*waveX
xtreg realprof amount amount_zone2 amount_zone3 wave2-wave9 zone2_wave2-zone2_wave9  zone3_wave2-zone3_wave9  if sample2==1, i(sheno) fe cluster(sheno)
test amount_zone2=amount_zone3

*TABLE 4
*returns to capital IV regressions
replace K2_noland=K2_noland/10000
gen hourlywage=prof/(ownhours*4.2)

*First caluculate profit adjusted for owner's hours worked, using coefficients from wage regression

*Allow 'wages' to vary with gender and education
gen gend=gender if wave==1
egen gender_1=mean(gender), by(sheno)

gen ednEN=ednyearsFIRM
gen femlow=gender_1==2 & ednEN<=7 if gender_1~=. & ednEN~=.
gen femmed=gender_1==2 & ednEN>=8 & ednEN<=10 if gender_1~=. & ednEN~=.
gen femhi=gender_1==2 & ednEN>=11 if gender_1~=. & ednEN~=.

gen malelow=gender_1==1 & ednEN<=7 if gender_1~=. & ednEN~=.
gen malemed=gender_1==1 & ednEN>=8 & ednEN<=10 if gender_1~=. & ednEN~=.
gen malehi=gender_1==1 & ednEN>=11 if gender_1~=. & ednEN~=.

for var femlow femmed femhi malelow malemed malehi: sum hourlywage if X==1, det
gen mcat_hourly=7.9 if femlow==1
replace mcat_hourly=11.9 if femmed==1
replace mcat_hourly=10.6 if femhi==1
replace mcat_hourly=15.9 if malelow==1
replace mcat_hourly=17.3 if malemed==1
replace mcat_hourly=15.1 if malehi==1

for var femlow femmed femhi malelow malemed malehi:gen hours_X=(ownhours*4.2)*X

*Use coefficeints from this regression:
reg prof age  femlow femmed femhi malelow malemed malehi K2_noland  hours_femlow- hours_malehi if wave==1
gen reg_hourlywage=0 if femlow==1 | femmed==1
replace reg_hourlywage=9.3 if femhi==1
replace reg_hourlywage=3.0 if malelow==1
replace reg_hourlywage=4.8 if malemed==1
replace reg_hourlywage=7.5 if malehi==1

gen adjprof3=realprof-(reg_hourlywage*4.2*ownhours)
gen adjprof4=realprof-(mcat_hourly*4.2*ownhours)

xtivreg2 realprof (K2_nolandnew=amount) wave2-wave9   if sample2==1, i(sheno) fe  first cluster(sheno)
xtivreg2 logprof (lK2_nolandnew=amount) wave2-wave9   if sample2==1, i(sheno) fe  first cluster(sheno)

* Using all four treatments as instruments for capital, compare to amount
xtivreg2 realprof (K2_nolandnew=equip100 equip200 cash100 cash200) wave2-wave9   if sample2==1, i(sheno) fe  first cluster(sheno)

*use median hourly earnings in each of six categories
xtivreg2 adjprof3 (K2_nolandnew=amount) wave2-wave9   if sample2==1, i(sheno) fe  first cluster(sheno)
*use regression coefficents by category
xtivreg2 adjprof4 (K2_nolandnew=amount) wave2-wave9   if sample2==1, i(sheno) fe  first cluster(sheno)


*TABLE 5 -- HETEROGENEITY OF IMPACTS
*---gender interactions---*
gen amount_femaleverified=amount*femaleverified
for num 2/10: gen femaleverified_waveX=femaleverified*waveX
gen K_noland_femaleverified=K2_noland*femaleverified

xtreg realprof amount amount_female wave2-wave9   femaleverified_wave2-femaleverified_wave9 if ets>1 & sample2==1, fe i(sheno) cluster (sheno)

*interaction effects
***Note: There are two small glitches here, neither of consequence. First, the adjusted profits regressions use years of schooling reported in 
***the enterprise survey, and here we use years of schooling reported in the household survey. These occaisionaly differ. Second, after the original  
***results were run, we found a minor error in the digitspan data. Those who were not able to repeat the 3-digit number had been coded as missing.
***They are now coded as "3", as they should be.

gen p_ednyears=ednyears
for var nwageworkers otherbusworkers assetindex p_ednyears p_digitspan p_ability3  coeffvar p_lotBcrra overallliferisk   : egen m_X=mean(X)
 for var nwageworkers otherbusworkers assetindex p_ednyears p_digitspan p_ability3  coeffvar p_lotBcrra overallliferisk  :   gen dm_X=X-m_X

for var  nwageworkers otherbusworkers assetindex p_ednyears p_digitspan  p_ability3  coeffvar p_lotBcrra overallliferisk  :gen amount_X=amount*dm_X
for num 2/9: gen nwageworkers_waveX=dm_nwageworkers*waveX
for num 2/9: gen otherbusworkers_waveX=dm_otherbusworkers*waveX
for num 2/9: gen assetindex_waveX=dm_assetindex*waveX
for num 2/9: gen p_ednyears_waveX=dm_p_ednyears*waveX
for num 2/9: gen p_digitspan_waveX=dm_p_digitspan*waveX
for num 2/9: gen p_ability3_waveX=dm_p_ability3*waveX
for num 2/9: gen coeffvar_waveX=dm_coeffvar*waveX
for num 2/9: gen p_lotBcrra_waveX=dm_p_lotBcrra*waveX
for num 2/9: gen overallliferisk_waveX=dm_overallliferisk*waveX

xtreg realprof amount amount_nwageworkers amount_assetindex amount_p_ednyears amount_p_digitspan ///
 wave2-wave9   nwageworkers_wave2-nwageworkers_wave9 assetindex_wave2-assetindex_wave9 ///
 p_ednyears_wave2-p_ednyears_wave9 p_digitspan_wave2-p_digitspan_wave9 if ets>1 & sample2==1 & p_digitspan>3, fe i(sheno) cluster (sheno)


*risk and uncertainty
xtreg realprof amount amount_coeffvar amount_p_lotBcrra ///
 wave2-wave9   coeffvar_wave2-coeffvar_wave9 p_lotBcrra_wave2-p_lotBcrra_wave9 if ets>1 & sample2==1, fe i(sheno) cluster (sheno)

*Split by males and females
xtreg realprof amount  amount_assetindex amount_p_ednyears amount_p_digitspan ///
 wave2-wave9    assetindex_wave2-assetindex_wave9 ///
 p_ednyears_wave2-p_ednyears_wave9 p_digitspan_wave2-p_digitspan_wave9 if ets>1 & sample2==1 & femaleverified==1, fe i(sheno) cluster (sheno)
gen returnf=_b[amount]+_b[amount_assetindex]*dm_assetindex+_b[amount_p_ednyears]*dm_p_ednyears+_b[amount_p_digitspan]*dm_p_digitspan if femaleverified==1

xtreg realprof amount  amount_assetindex amount_p_ednyears amount_p_digitspan ///
 wave2-wave9    assetindex_wave2-assetindex_wave9 ///
 p_ednyears_wave2-p_ednyears_wave9 p_digitspan_wave2-p_digitspan_wave9 if ets>1 & sample2==1 & femaleverified==0, fe i(sheno) cluster (sheno)
gen returnm=_b[amount]+_b[amount_assetindex]*dm_assetindex+_b[amount_p_ednyears]*dm_p_ednyears+_b[amount_p_digitspan]*dm_p_digitspan if femaleverified==0


*TABLE 6 SPILLOVERS
gen narrow500m=0
replace narrow500m=narrowfirmsetreat500m if wave==2|wave==3
replace narrow500m=narrowfirmstreat500m if wave>=4
gen narrow1k=0
replace narrow1k=narrowfirmsetreat1k if wave==2|wave==3
replace narrow1k=narrowfirmstreat1k if wave>=4
gen narrow5k=0
replace narrow5k=narrowfirmsetreat5k if wave==2|wave==3
replace narrow5k=narrowfirmstreat5k if wave>=4
gen broad500m=0
replace broad500m=firmsinindustryetreat500m if wave==2|wave==3
replace broad500m=firmsinindustrytreat500m if wave>=4
gen broad1k=0
replace broad1k=firmsinindustryetreat1k if wave==2|wave==3
replace broad1k=firmsinindustrytreat1k if wave>=4
gen broad5k=0
replace broad5k=firmsinindustryetreat5k if wave==2|wave==3
replace broad5k=firmsinindustrytreat5k if wave>=4

xtreg realprof amount narrow500m wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)
xtreg realprof amount broad500m wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)

xtreg realprof amount narrow1k wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)
xtreg realprof amount broad1k wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)

xtivreg2 adjprof3 (K2_nolandnew=amount) narrow500m wave2-wave9   if sample2==1, i(sheno) fe first cluster(sheno)
xtivreg2 adjprof3 (K2_nolandnew=amount) narrow1k wave2-wave9   if sample2==1, i(sheno) fe first cluster(sheno)


*Heterogenety with spillovers
gen narrow500m_fem=narrow500m* femaleverified
for var nwageworkers otherbusworkers assetindex p_ednyears p_digitspan p_ability3  coeffvar p_lotBcrra overallliferisk   : gen narrow500m_X=narrow500m*X

xtreg realprof amount amount_female narrow500m narrow500m_fem wave2-wave9   femaleverified_wave2-femaleverified_wave9 if ets>1 & sample2==1, fe i(sheno) cluster (sheno)



*TABLE 7: NON_EXPERIMENTAL VS> EXPERIMENTAL
*returns in the cross section and the untreated panel
reg adjprof3 age femaleverified ednyears K2_nolandnew  if wave==1 & sample2==1
xtreg adjprof3 age femaleverified ednyears K2_nolandnew wave2-wave9 if evertreat==0 & sample2==1 & wave<=5, re i(sheno) cluster(sheno)
xtreg adjprof3 age femaleverified ednyears K2_nolandnew wave2-wave9 if evertreat==0 & sample2==1 & wave<=5, fe i(sheno) cluster(sheno)
xtivreg2 adjprof3 (K2_nolandnew=amount) wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)

for var age ednyears K2_noland: gen lX=log(X)
*Logs
reg logprof lage femaleverified lednyears lK2_nolandnew  if wave==1 & sample2==1
xtreg logprof lage femaleverified lednyears lK2_nolandnew wave2-wave9 if evertreat==0 & sample2==1 & wave<=5, re i(sheno) cluster(sheno)
xtreg logprof lage femaleverified lednyears lK2_nolandnew wave2-wave9 if evertreat==0 & sample2==1 & wave<=5, fe i(sheno) cluster(sheno)
xtivreg2 logprof (lK2_nolandnew=amount) wave2-wave9   if sample2==1, i(sheno) fe cluster(sheno)




***TABLE 1: COMPARISON OF MEANS BASED ON ASSIGNMENT TO TREATMENT
*comparison of beaseline treated/untreated samples 
*gen K=(K2_nolandnew)+land
*Evertreated is 0/1/2. Change to 0/1, then add firms assigned but not treated 
gen evertreated=evertreat==1 | evertreat==2 if evertreat~=. 
replace evertreated=1 if sheno==70|sheno==102|sheno==203|sheno==208|sheno==260|sheno==296|sheno==452|sheno==650
tab evertreated if wave==1

gen register =registerDS + registerPS + registerPG
sum prof rev K K2_nolandnew ownhours famhours age agebus femaleverified ednEN fatherbus register  nwageworkers assetindex p_digitspan  lotBcrra if wave==1 
sum prof rev K K2_nolandnew ownhours famhours age agebus femaleverified ednEN fatherbus register  nwageworkers assetindex p_digitspan  lotBcrra if wave==1 ///
& evertreated==0 
sum prof rev K K2_nolandnew ownhours famhours age agebus femaleverified ednEN fatherbus register  nwageworkers assetindex p_digitspan  lotBcrra if wave==1 ///
& evertreated==1 

for var  prof rev K K2_nolandnew ownhours famhours age agebus femaleverified ednEN fatherbus register  nwageworkers assetindex p_digitspan  lotBcrra ///
      : ttest X if wave==1 , by(evertreated) 


log close


